@@ -344,6 +344,7 @@ class Setup:
             TestCase( self.c_pysvn, '08', (1,7,0) ),
             TestCase( self.c_pysvn, '09', (1,7,0) ),
             TestCase( self.c_pysvn, '10', (1,9,0) ),
+            TestCase( self.c_pysvn, '11', (1,10,0) ),
             ] )
 
         all_extra_test_cases = self.__filterTestCases( [
@@ -992,7 +993,7 @@ class CompilerGCC(Compiler):
         rules.append( '' )
         rules.append( 'test-%(TN)s.unix.new.log: test-%(TN)s.sh test-%(TN)s.unix.known_good-%(KGV)s.log' % v )
         rules.append( '\t' '-rm -rf testroot-%(TN)s' % v )
-        rules.append( '\t' 'LD_LIBRARY_PATH=%%(SVN_LIB)s:%%(APR_LIB)s PATH=%%(SVN_BIN)s:$(PATH) PYTHON=%%(PYTHON)s ./test-%(TN)s.sh >test-%(TN)s.unix.new.log 2>&1' % v )
+        rules.append( '\t' 'LD_LIBRARY_PATH="%%(SVN_LIB)s:%%(APR_LIB)s" PATH="%%(SVN_BIN)s:$(PATH)" PYTHON="%%(PYTHON)s" ./test-%(TN)s.sh >test-%(TN)s.unix.new.log 2>&1' % v )
         rules.append( '' )
         rules.append( 'test-%(TN)s.unix.new.log.clean: test-%(TN)s.unix.new.log' % v )
         rules.append( '\t' '%%(PYTHON)s benchmark_diff.py %(SVN_VERSION)s test-%(TN)s.unix.known_good-%(KGV)s.log test-%(TN)s.unix.new.log' % v )
